The PCAF Workflows
--------------------

The CIRIS Methodology is an *attribution* and *reporting* methodology for Cities. It implements the GPC Recommendations for Community-Scale emissions accounting (See References).

The following steps replicate the PCAF workflow
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
* GPC Sectors: Stationary energy, Transportation and Waste must be completed for a BASIC inventory.
* Each sector is broken down by sub-sector and scope, using the GPC referencing system. [FORMULAS]
* Select the number of rows you will need from the drop-down list under 'Add'. You will need to do this for each emission category (sub-sector / scope).
* For each sub-sector, select an activity from the drop-down list e.g. natural gas. If your activity does not appear in the drop-down list, please enter this in yourself.
* For the Stationary sector you will also need to select a sub-category; for Transportation the boundary system methodology; and for the Waste sector the type of waste.
* If data are not available for an emission category (sub-sector/scope), notation keys should be used. Select the appropriate notation key from the drop-down list.
* Next, you will be asked to enter activity data. If the units are different to the denominator of the emission factor used, use the activity data multiplier function to convert.
* To use the activity data multiplier, select the unit you wish to convert your activity data into. Alternatively, you can enter your own conversion factor in the override column.
* Select the greenhouse gases included in your calculations from the drop-down list.
* Select an emission factor from the drop-down list. These are the ones you will have defined earlier in the Emission factors sheet. They are shown here in tonnes of CO2e.
* Alternatively, if you do not have an emission factor for a specific activity, you may enter emissions data directly. Make sure this is reported in metric tonnes of CO2e.
* To report emission data directly, select the tick mark (a) from the drop-down list and enter emissions data under the appropriate GHG.
* The oxidation factor for combustion has been set to 1. This appears in the Oxidation factor column when you enter data. Use the override column to choose a different value.
* The tool then calculates emissions based on the data submitted, in metric tonnes of CO2e.
* Assess the quality of your activity data in the Data quality column. Choose from high, medium or low. You can provide an optional explanation in the final column.
* You must also provide a clear description of the methodologies you have used. If you have used a notation key, please provide an explanation.
* Finally, select a data source from the drop-down list which lists all the references you defined in the Data sources sheet.
* Repeat the above process for all emission sources in your city.
* The estimated emissions can be found in the Results section.
